#!/bin/sh

APT_GET="apt-get -y --force-yes -q"
DPKG="dpkg --abort-after 999999"
BASE_PACKAGES="\
 libeet0 \
 libevas0 \
 libecore0 \
 libembryo0 \
 libepeg0 \
 libdownloadmanager0 \
 libimlib2 \
 liblightmediascanner0 \
 atabake \
 python2.5-dispatcher \
 python2.5-downloadmanager \
 python2.5-efl-utils" #XXX 

# FIXME: python2.5-efl-utils should be in EXTRA_PACKAGES,
# but due to a dependency problem in the debian package
# it is not being uninstalled automatically.
EXTRA_PACKAGES="\
 canola-tuning \
 python2.5-edje-demo \
 expedite \
 python-efl-core-demo \
 python-efl-core \
 ogg-support-lms"


CLEAN_PATHS="\
 /home/user/.canola \
 /usr/lib/python2.5/site-packages/atabake \
 /usr/lib/python2.5/site-packages/canolad \
 /usr/lib/python2.5/site-packages/dispatcher \
 /usr/lib/python2.5/site-packages/downloadmanager \
 /usr/lib/python2.5/site-packages/ecore \
 /usr/lib/python2.5/site-packages/edje \
 /usr/lib/python2.5/site-packages/efl_utils \
 /usr/lib/python2.5/site-packages/epsilon \
 /usr/lib/python2.5/site-packages/etk \
 /usr/lib/python2.5/site-packages/evas \
 /usr/lib/python2.5/site-packages/lightmediascanner \
 /usr/lib/python2.5/site-packages/terra"

die()
{
    echo "### ERROR: $*"
    exit 1
}

info()
{
    echo "### INFO: $*"
}

warning()
{
    echo "### WARN: $*"
}

important()
{
    echo "### IMPORTANT: $*"
}

report_exit()
{
    if [ $1 -eq 0 ]; then
        STATUS="OK"
    else
        STATUS="FAILED, code=$1"
    fi
    echo "### COMMAND_STATUS: $STATUS"
}

report_cmd()
{
    echo "### COMMAND: $*"
    sh -c "$*"
    ret=$?
    report_exit $ret
    return $ret
}

get_software_raw()
{
    cut -d_ -f2 /etc/osso_software_version
}

get_software()
{
    HW=$1
    VER=`get_software_raw`
    case $HW in
        770)
            case $VER in
                2006SE)
                    echo "gregale"
                    ;;
                2007HACKER)
                    echo "hackeredition"
                    ;;
                *)
                    echo "UNKNOWN"
                    ;;
            esac
            ;;
        N800)
            case $VER in
                2007SE)
                    echo "bora"
                    ;;
                2008SE)
                    echo "chinook"
                    ;;
                *)
                    echo "UNKNOWN"
                    ;;
            esac
            ;;
        N810)
            case $VER in
                2008SE)
                    echo "chinook"
                    ;;
                *)
                    echo "UNKNOWN"
                    ;;
            esac
            ;;
        *)
            echo "UNKNOWN"
            ;;
    esac
}

get_hardware_raw()
{
    grep product /proc/component_version | \
        sed 's/^[^ ]\+[ ]\+\([a-zA-Z0-9]\+\)/\1/g'
}

get_hardware()
{
    N=`get_hardware_raw`
    case $N in
        SU-18)
            echo "770"
            ;;
        RX-34)
            echo "N800"
            ;;
        RX-44)
            echo "N810"
            ;;
        *)
            echo "UNKNOWN"
            ;;
    esac
}

plat_info_report()
{
    important "Platform Information to Report"
    important "HARDWARE: `get_hardware_raw`"
    important "SOFTWARE: `get_software_raw`"
}

apt_clean()
{
    important "Trying to clean apt-get cache"
    report_cmd $APT_GET clean
}

apt_remove()
{
    important "Trying to remove packages using apt-get"
    report_cmd $APT_GET --purge remove $BASE_PACKAGES
}

apt_f_install()
{
    report_cmd $APT_GET -f install
}

dpkg_configure_pending()
{
    report_cmd $DPKG --force-all --configure -a
}

clean_paths()
{
    for p in $CLEAN_PATHS; do
        if [ -d $p ]; then
            report_cmd rm -fr $p
        fi
    done
}

dpkg_remove_extras()
{
    report_cmd $DPKG --purge $EXTRA_PACKAGES
}

dpkg_remove_770_gregale()
{
    report_cmd $DPKG --purge canola2 canolad python2.5-terra python2.5-efl-core python2.5-edje efl-core libetk0-engine-all libetk0-engine-evas-software-x11-16 libetk0-engine-evas-software-x11 libetk0 python2.5-epsilon libepsilon0 libetk0-engine-evas epsilon0-bin python2.5-etk libedje0 libecore0-all libecore0-imf-evas libevas0-all libevas0-loaders-all libembryo0 libetk0-engine-evas-x11 python2.5-evas libevas0-engines-all libevas0-engine-software-x11 libevas0-loader-png hildon-imf-ecore python2.5-ecore libecore0-evas libecore0-x libecore0-job libecore0-ipc libecore0-desktop libecore0-con libecore0-imf python2.5-dbus-ecore libedbus0 libecore0-file libecore0-txt libecore0 libevas0-engine-buffer libevas0-loader-jpeg libevas0-engine-software-x11-16 libevas0-engine-software-generic libevas0-savers-all libevas0-saver-jpeg libevas0-loader-eet libevas0-saver-eet libevas0-saver-png libevas0 libeet0 libimlib2 libepeg0
}

dpkg_remove_770_hackeredition()
{
    # try both to remove from hacker edition users that not followed the
    # instructions to remove "bora" repositories before installing Canola
    dpkg_remove_770_gregale
    dpkg_remove_N800_bora
}

dpkg_remove_N800_bora()
{
    report_cmd $DPKG --purge canola2 canolad python2.5-terra python2.5-efl-core python2.5-edje python2.5-epsilon libepsilon0 efl-core python2.5-etk libedje0 libecore0-imf-evas libevas0-all libevas0-loaders-all libembryo0 libetk0-engine-all libetk0-engine-evas-software-x11 libetk0-engine-evas-x11 libetk0 libetk0-engine-evas-software-x11-16 python2.5-evas libevas0-engines-all python2.5-ecore libecore0-evas libevas0-engine-software-x11 libevas0-loader-png hildon-imf-ecore libecore0-x libecore0-job libecore0-txt python2.5-dbus-ecore libedbus0 libecore0-file libecore0-con libecore0 libecore0-all libecore0-desktop libecore0-imf libevas0-engine-buffer libevas0-loader-jpeg libevas0-engine-software-x11-16 libevas0-engine-software-generic libevas0-savers-all libevas0-saver-jpeg libevas0-loader-eet libevas0-saver-eet libevas0-saver-png libevas0 epsilon0-bin libecore0-ipc libetk0-engine-evas libeet0 libimlib2 libepeg0
}

dpkg_remove_N800_chinook()
{
    report_cmd $DPKG --purge canola2 canolad python2.5-terra python2.5-efl-core python2.5-edje python2.5-epsilon libepsilon0 efl-core python2.5-etk libedje0 libecore0-imf-evas libevas0-all libevas0-loaders-all libembryo0 libetk0-engine-all libetk0-engine-evas-software-x11 libetk0-engine-evas-x11 python2.5-evas libevas0-engines-all libetk0 python2.5-ecore libecore0-evas libevas0-engine-software-x11 libevas0-loader-png hildon-imf-ecore libecore0-x libecore0-job python2.5-edbus libetk0-engine-evas-software-x11-16 libecore0-con libedbus0 libecore0-file libecore0-txt libecore0 libecore0-all libecore0-desktop libecore0-imf epsilon0-bin libevas0-engine-buffer libevas0-loader-jpeg libevas0-engine-software-x11-16 libevas0-engine-software-generic libevas0-savers-all libevas0-saver-jpeg libevas0-loader-eet libevas0-saver-eet libevas0-saver-png libevas0 libecore0-ipc libetk0-engine-evas libeet0 libimlib2 libepeg0
}

dpkg_remove_N810_chinook()
{
    report_cmd $DPKG --purge canola2 canolad python2.5-terra python2.5-efl-core python2.5-edje python2.5-epsilon libepsilon0 efl-core python2.5-etk libedje0 libecore0-imf-evas libevas0-all libevas0-loaders-all libembryo0 libetk0-engine-all libetk0-engine-evas-software-x11 libetk0-engine-evas-x11 python2.5-evas libevas0-engines-all libetk0 python2.5-ecore libecore0-evas libevas0-engine-software-x11 libevas0-loader-png hildon-imf-ecore libecore0-x libecore0-job python2.5-edbus libetk0-engine-evas-software-x11-16 libecore0-con libedbus0 libecore0-file libecore0-txt libecore0 libecore0-all libecore0-desktop libecore0-imf epsilon0-bin libevas0-engine-buffer libevas0-loader-jpeg libevas0-engine-software-x11-16 libevas0-engine-software-generic libevas0-savers-all libevas0-saver-jpeg libevas0-loader-eet libevas0-saver-eet libevas0-saver-png libevas0 libecore0-ipc libetk0-engine-evas libeet0 libimlib2 libepeg0
}

dpkg_remove()
{
    important "Trying to remove packages with dpkg"
    dpkg_remove_extras
    dpkg_remove_${HARDWARE}_${SOFTWARE}
}

apt_worker_pid=`pidof apt-worker`
test ! -z "$apt_worker_pid" && die "Application Installer is running."
export HARDWARE=`get_hardware`
export SOFTWARE=`get_software $HARDWARE`
if [ $HARDWARE = "UNKNOWN" ] || [ $SOFTWARE = "UNKNOWN" ]; then
    plat_info_report
    die "Unsupported platform, please report"
fi


apt_clean
apt_f_install
dpkg_configure_pending
apt_remove || dpkg_remove
clean_paths

